@@ -51,7 +51,7 @@ extern "C"
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "2.2.0"
+#define OATH_VERSION "2.4.0"
 
 /**
  * OATH_VERSION_NUMBER
@@ -61,7 +61,7 @@ extern "C"
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x02020000
+#define OATH_VERSION_NUMBER 0x02040000
 
 /**
  * oath_rc:
@@ -275,6 +275,30 @@ oath_totp_validate2_callback (const char *secret,
 			      oath_validate_strcmp_function strcmp_otp,
 			      void *strcmp_handle);
 
+extern OATHAPI int
+oath_totp_validate3 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     size_t window,
+		     int *otp_pos,
+		     uint64_t *otp_counter,
+		     const char *otp);
+
+extern OATHAPI int
+oath_totp_validate3_callback (const char *secret,
+			      size_t secret_length,
+			      time_t now,
+			      unsigned time_step_size,
+			      time_t start_offset,
+			      unsigned digits,
+			      size_t window,
+			      int *otp_pos,
+			      uint64_t *otp_counter,
+			      oath_validate_strcmp_function strcmp_otp,
+			      void *strcmp_handle);
+
 /* Usersfile */
 
 extern OATHAPI int
